Changelog — mlPyp 0.2.0 documentation

# Changelog

## 0.2.0

- Now the datasets are saved in hdf5 format
- The datasets can be splited, and models can be trained in folds
- Added a new class for integrate transformations to the data
- You can choice if the datasets are saved with applied tranformations or not
- Examples for data operations are described in the example’s section
- Added ensembled models (Bagging, Stacking, Boosting)

## 0.1.1

- Added Auto Encoder class
- Added parametric tsne

## 0.1.0

- Initial version